@@ -77,9 +77,7 @@ def plot_graph_coords(vcoords, ecoords, plotpath, ax, shppath):
         mapx, mapy = get_shp_points(shppath)
         ax.plot(mapx, mapy, c='dimgray')
 
-    ax.axis('off')
-    plt.tight_layout()
-    plt.savefig(plotpath)
+    return ax
 
 ##########################################################
 def plot_graph(gin, plotpath='/tmp/mygraph.png', inverty=False, ax='', shppath=''):
@@ -104,4 +102,7 @@ def plot_graph(gin, plotpath='/tmp/mygraph.png', inverty=False, ax='', shppath='
         ecoords.append([ [float(g.vs[e.source]['x']), float(g.vs[e.source]['y'])],
                 [float(g.vs[e.target]['x']), float(g.vs[e.target]['y'])], ])
 
-    plot_graph_coords(vcoords, ecoords, plotpath, ax, shppath)
+    ax = plot_graph_coords(vcoords, ecoords, plotpath, ax, shppath)
+    ax.axis('off')
+    plt.tight_layout()
+    plt.savefig(plotpath)
